@@ -9,13 +9,14 @@ if sys.version_info >= (3, 11):
 else:
     from typing_extensions import Self
 
-
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, ValidationError
 from xmltodict import parse as xml_parse
 
+from ..exceptions import OmniParsingException
 from ..types import (
     BodyOfWaterType,
     ColorLogicLightType,
+    ColorLogicShow,
     FilterType,
     HeaterType,
     OmniType,
@@ -141,6 +142,11 @@ class MSPColorLogicLight(OmniBase):
     omni_type: OmniType = OmniType.CL_LIGHT
     type: ColorLogicLightType | str = Field(alias="Type")
     v2_active: Literal["yes", "no"] | None = Field(alias="V2-Active")
+    effects: list[ColorLogicShow] | None
+
+    def __init__(self, **data: Any) -> None:
+        super().__init__(**data)
+        self.effects = list(ColorLogicShow) if self.v2_active == "yes" else [show for show in ColorLogicShow if show.value <= 16]
 
 
 class MSPBoW(OmniBase):
@@ -209,4 +215,7 @@ class MSPConfig(BaseModel):
                 OmniType.SCHE,
             ),
         )
-        return MSPConfig.parse_obj(data["MSPConfig"])
+        try:
+            return MSPConfig.parse_obj(data["MSPConfig"])
+        except ValidationError as exc:
+            raise OmniParsingException(f"Failed to parse MSP Configuration: {exc}") from exc
